Struct rustc::middle::stability::DeprecationEntry
[−]
[src]
pub struct DeprecationEntry {
pub attr: Deprecation,
// some fields omitted
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
An entry in the depr_map.
Fields
attr: Deprecation
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
The metadata of the attribute associated with this entry.
Methods
impl DeprecationEntry[src]
pub fn external(attr: Deprecation) -> DeprecationEntry[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
pub fn same_origin(&self, other: &DeprecationEntry) -> bool[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?